import React from 'react';

export default class MediaObject extends React.Component {
  render() {
    return (
<main className="col-12 col-md-9 col-xl-8 py-md-3 pl-md-5 bd-content" role="main">
  <h1 className="bd-title" id="content">Media object</h1>
  <p className="bd-lead">Documentation and examples for Bootstrap’s media object to construct highly repetitive components like blog comments, tweets, and the like.</p>

  <h2>To do</h2>
  <ul>
    <li>Delete</li>
  </ul>

  <h2 id="example"><span className="bd-content-title">Example</span></h2>
  <p>The <a href="http://www.stubbornella.org/content/2010/06/25/the-media-object-saves-hundreds-of-lines-of-code/">media object</a> helps build complex and repetitive components where some media is positioned alongside content that doesn’t wrap around said media. Plus, it does this with only two required classes thanks to flexbox.</p>
  <p>Below is an example of a single media object. Only two classes are required—the wrapping <code className="highlighter-rouge">.media</code> and the <code className="highlighter-rouge">.media-body</code> around your content. Optional padding and margin can be controlled through <a href="/docs/4.2/utilities/spacing/">spacing utilities</a>.</p>
  <div className="bd-example">
    <div className="media">
      <svg className="bd-placeholder-img mr-3" width={64} height={64} xmlns="http://www.w3.org/2000/svg" preserveAspectRatio="xMidYMid slice" focusable="false" role="img" aria-label="Placeholder: 64x64"><title>Placeholder</title><rect fill="#868e96" width="100%" height="100%" /><text fill="#dee2e6" dy=".3em" x="50%" y="50%">64x64</text></svg>
      <div className="media-body">
        <h5 className="mt-0">Media heading</h5>
        Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.
      </div>
    </div>
  </div>
  <div className="bd-clipboard"><button type="button" className="btn-clipboard" title data-original-title="Copy to clipboard">Copy</button></div><figure className="highlight"><pre><code className="language-html" data-lang="html"><span className="nt">&lt;div</span> <span className="na">class=</span><span className="s">"media"</span><span className="nt">&gt;</span>{"\n"}{"  "}<span className="nt">&lt;img</span> <span className="na">src=</span><span className="s">"..."</span> <span className="na">class=</span><span className="s">"mr-3"</span> <span className="na">alt=</span><span className="s">"..."</span><span className="nt">&gt;</span>{"\n"}{"  "}<span className="nt">&lt;div</span> <span className="na">class=</span><span className="s">"media-body"</span><span className="nt">&gt;</span>{"\n"}{"    "}<span className="nt">&lt;h5</span> <span className="na">class=</span><span className="s">"mt-0"</span><span className="nt">&gt;</span>Media heading<span className="nt">&lt;/h5&gt;</span>{"\n"}{"    "}Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.{"\n"}{"  "}<span className="nt">&lt;/div&gt;</span>{"\n"}<span className="nt">&lt;/div&gt;</span></code></pre></figure>
  <div className="bd-callout bd-callout-warning">
    <h5 id="flexbug-12-inline-elements-arent-treated-as-flex-items">Flexbug #12: Inline elements aren’t treated as flex items</h5>
    <p>Internet Explorer 10-11 do not render inline elements like links or images (or <code className="highlighter-rouge">::before</code> and <code className="highlighter-rouge">::after</code> pseudo-elements) as flex items. The only workaround is to set a non-inline <code className="highlighter-rouge">display</code> value (e.g., <code className="highlighter-rouge">block</code>, <code className="highlighter-rouge">inline-block</code>, or <code className="highlighter-rouge">flex</code>). We suggest using <code className="highlighter-rouge">.d-flex</code>, one of our <a href="/docs/4.2/utilities/display/">display utilities</a>, as an easy fix.</p>
    <p><strong>Source:</strong> <a href="https://github.com/philipwalton/flexbugs#flexbug-12">Flexbugs on GitHub</a></p>
  </div>
  <h2 id="nesting"><span className="bd-content-title">Nesting</span></h2>
  <p>Media objects can be infinitely nested, though we suggest you stop at some point. Place nested <code className="highlighter-rouge">.media</code> within the <code className="highlighter-rouge">.media-body</code> of a parent media object.</p>
  <div className="bd-example">
    <div className="media">
      <svg className="bd-placeholder-img mr-3" width={64} height={64} xmlns="http://www.w3.org/2000/svg" preserveAspectRatio="xMidYMid slice" focusable="false" role="img" aria-label="Placeholder: 64x64"><title>Placeholder</title><rect fill="#868e96" width="100%" height="100%" /><text fill="#dee2e6" dy=".3em" x="50%" y="50%">64x64</text></svg>
      <div className="media-body">
        <h5 className="mt-0">Media heading</h5>
        Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.
        <div className="media mt-3">
          <a className="mr-3" href="#demo">
            <svg className="bd-placeholder-img" width={64} height={64} xmlns="http://www.w3.org/2000/svg" preserveAspectRatio="xMidYMid slice" focusable="false" role="img" aria-label="Placeholder: 64x64"><title>Placeholder</title><rect fill="#868e96" width="100%" height="100%" /><text fill="#dee2e6" dy=".3em" x="50%" y="50%">64x64</text></svg>
          </a>
          <div className="media-body">
            <h5 className="mt-0">Media heading</h5>
            Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.
          </div>
        </div>
      </div>
    </div>
  </div>
  <div className="bd-clipboard"><button type="button" className="btn-clipboard" title data-original-title="Copy to clipboard">Copy</button></div><figure className="highlight"><pre><code className="language-html" data-lang="html"><span className="nt">&lt;div</span> <span className="na">class=</span><span className="s">"media"</span><span className="nt">&gt;</span>{"\n"}{"  "}<span className="nt">&lt;img</span> <span className="na">src=</span><span className="s">"..."</span> <span className="na">class=</span><span className="s">"mr-3"</span> <span className="na">alt=</span><span className="s">"..."</span><span className="nt">&gt;</span>{"\n"}{"  "}<span className="nt">&lt;div</span> <span className="na">class=</span><span className="s">"media-body"</span><span className="nt">&gt;</span>{"\n"}{"    "}<span className="nt">&lt;h5</span> <span className="na">class=</span><span className="s">"mt-0"</span><span className="nt">&gt;</span>Media heading<span className="nt">&lt;/h5&gt;</span>{"\n"}{"    "}Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.{"\n"}{"\n"}{"    "}<span className="nt">&lt;div</span> <span className="na">class=</span><span className="s">"media mt-3"</span><span className="nt">&gt;</span>{"\n"}{"      "}<span className="nt">&lt;a</span> <span className="na">class=</span><span className="s">"mr-3"</span> <span className="na">href=</span><span className="s">"#"</span><span className="nt">&gt;</span>{"\n"}{"        "}<span className="nt">&lt;img</span> <span className="na">src=</span><span className="s">"..."</span> <span className="na">class=</span><span className="s">"mr-3"</span> <span className="na">alt=</span><span className="s">"..."</span><span className="nt">&gt;</span>{"\n"}{"      "}<span className="nt">&lt;/a&gt;</span>{"\n"}{"      "}<span className="nt">&lt;div</span> <span className="na">class=</span><span className="s">"media-body"</span><span className="nt">&gt;</span>{"\n"}{"        "}<span className="nt">&lt;h5</span> <span className="na">class=</span><span className="s">"mt-0"</span><span className="nt">&gt;</span>Media heading<span className="nt">&lt;/h5&gt;</span>{"\n"}{"        "}Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.{"\n"}{"      "}<span className="nt">&lt;/div&gt;</span>{"\n"}{"    "}<span className="nt">&lt;/div&gt;</span>{"\n"}{"  "}<span className="nt">&lt;/div&gt;</span>{"\n"}<span className="nt">&lt;/div&gt;</span></code></pre></figure>
  <h2 id="alignment"><span className="bd-content-title">Alignment</span></h2>
  <p>Media in a media object can be aligned with flexbox utilities to the top (default), middle, or end of your <code className="highlighter-rouge">.media-body</code> content.</p>
  <div className="bd-example">
    <div className="media">
      <svg className="bd-placeholder-img align-self-start mr-3" width={64} height={64} xmlns="http://www.w3.org/2000/svg" preserveAspectRatio="xMidYMid slice" focusable="false" role="img" aria-label="Placeholder: 64x64"><title>Placeholder</title><rect fill="#868e96" width="100%" height="100%" /><text fill="#dee2e6" dy=".3em" x="50%" y="50%">64x64</text></svg>
      <div className="media-body">
        <h5 className="mt-0">Top-aligned media</h5>
        <p>Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.</p>
        <p>Donec sed odio dui. Nullam quis risus eget urna mollis ornare vel eu leo. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus.</p>
      </div>
    </div>
  </div>
  <div className="bd-clipboard"><button type="button" className="btn-clipboard" title data-original-title="Copy to clipboard">Copy</button></div><figure className="highlight"><pre><code className="language-html" data-lang="html"><span className="nt">&lt;div</span> <span className="na">class=</span><span className="s">"media"</span><span className="nt">&gt;</span>{"\n"}{"  "}<span className="nt">&lt;img</span> <span className="na">src=</span><span className="s">"..."</span> <span className="na">class=</span><span className="s">"align-self-start mr-3"</span> <span className="na">alt=</span><span className="s">"..."</span><span className="nt">&gt;</span>{"\n"}{"  "}<span className="nt">&lt;div</span> <span className="na">class=</span><span className="s">"media-body"</span><span className="nt">&gt;</span>{"\n"}{"    "}<span className="nt">&lt;h5</span> <span className="na">class=</span><span className="s">"mt-0"</span><span className="nt">&gt;</span>Top-aligned media<span className="nt">&lt;/h5&gt;</span>{"\n"}{"    "}<span className="nt">&lt;p&gt;</span>Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.<span className="nt">&lt;/p&gt;</span>{"\n"}{"    "}<span className="nt">&lt;p&gt;</span>Donec sed odio dui. Nullam quis risus eget urna mollis ornare vel eu leo. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus.<span className="nt">&lt;/p&gt;</span>{"\n"}{"  "}<span className="nt">&lt;/div&gt;</span>{"\n"}<span className="nt">&lt;/div&gt;</span></code></pre></figure>
  <div className="bd-example">
    <div className="media">
      <svg className="bd-placeholder-img align-self-center mr-3" width={64} height={64} xmlns="http://www.w3.org/2000/svg" preserveAspectRatio="xMidYMid slice" focusable="false" role="img" aria-label="Placeholder: 64x64"><title>Placeholder</title><rect fill="#868e96" width="100%" height="100%" /><text fill="#dee2e6" dy=".3em" x="50%" y="50%">64x64</text></svg>
      <div className="media-body">
        <h5 className="mt-0">Center-aligned media</h5>
        <p>Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.</p>
        <p className="mb-0">Donec sed odio dui. Nullam quis risus eget urna mollis ornare vel eu leo. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus.</p>
      </div>
    </div>
  </div>
  <div className="bd-clipboard"><button type="button" className="btn-clipboard" title data-original-title="Copy to clipboard">Copy</button></div><figure className="highlight"><pre><code className="language-html" data-lang="html"><span className="nt">&lt;div</span> <span className="na">class=</span><span className="s">"media"</span><span className="nt">&gt;</span>{"\n"}{"  "}<span className="nt">&lt;img</span> <span className="na">src=</span><span className="s">"..."</span> <span className="na">class=</span><span className="s">"align-self-center mr-3"</span> <span className="na">alt=</span><span className="s">"..."</span><span className="nt">&gt;</span>{"\n"}{"  "}<span className="nt">&lt;div</span> <span className="na">class=</span><span className="s">"media-body"</span><span className="nt">&gt;</span>{"\n"}{"    "}<span className="nt">&lt;h5</span> <span className="na">class=</span><span className="s">"mt-0"</span><span className="nt">&gt;</span>Center-aligned media<span className="nt">&lt;/h5&gt;</span>{"\n"}{"    "}<span className="nt">&lt;p&gt;</span>Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.<span className="nt">&lt;/p&gt;</span>{"\n"}{"    "}<span className="nt">&lt;p</span> <span className="na">class=</span><span className="s">"mb-0"</span><span className="nt">&gt;</span>Donec sed odio dui. Nullam quis risus eget urna mollis ornare vel eu leo. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus.<span className="nt">&lt;/p&gt;</span>{"\n"}{"  "}<span className="nt">&lt;/div&gt;</span>{"\n"}<span className="nt">&lt;/div&gt;</span></code></pre></figure>
  <div className="bd-example">
    <div className="media">
      <svg className="bd-placeholder-img align-self-end mr-3" width={64} height={64} xmlns="http://www.w3.org/2000/svg" preserveAspectRatio="xMidYMid slice" focusable="false" role="img" aria-label="Placeholder: 64x64"><title>Placeholder</title><rect fill="#868e96" width="100%" height="100%" /><text fill="#dee2e6" dy=".3em" x="50%" y="50%">64x64</text></svg>
      <div className="media-body">
        <h5 className="mt-0">Bottom-aligned media</h5>
        <p>Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.</p>
        <p className="mb-0">Donec sed odio dui. Nullam quis risus eget urna mollis ornare vel eu leo. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus.</p>
      </div>
    </div>
  </div>
  <div className="bd-clipboard"><button type="button" className="btn-clipboard" title data-original-title="Copy to clipboard">Copy</button></div><figure className="highlight"><pre><code className="language-html" data-lang="html"><span className="nt">&lt;div</span> <span className="na">class=</span><span className="s">"media"</span><span className="nt">&gt;</span>{"\n"}{"  "}<span className="nt">&lt;img</span> <span className="na">src=</span><span className="s">"..."</span> <span className="na">class=</span><span className="s">"align-self-end mr-3"</span> <span className="na">alt=</span><span className="s">"..."</span><span className="nt">&gt;</span>{"\n"}{"  "}<span className="nt">&lt;div</span> <span className="na">class=</span><span className="s">"media-body"</span><span className="nt">&gt;</span>{"\n"}{"    "}<span className="nt">&lt;h5</span> <span className="na">class=</span><span className="s">"mt-0"</span><span className="nt">&gt;</span>Bottom-aligned media<span className="nt">&lt;/h5&gt;</span>{"\n"}{"    "}<span className="nt">&lt;p&gt;</span>Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.<span className="nt">&lt;/p&gt;</span>{"\n"}{"    "}<span className="nt">&lt;p</span> <span className="na">class=</span><span className="s">"mb-0"</span><span className="nt">&gt;</span>Donec sed odio dui. Nullam quis risus eget urna mollis ornare vel eu leo. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus.<span className="nt">&lt;/p&gt;</span>{"\n"}{"  "}<span className="nt">&lt;/div&gt;</span>{"\n"}<span className="nt">&lt;/div&gt;</span></code></pre></figure>
  <h2 id="order"><span className="bd-content-title">Order</span></h2>
  <p>Change the order of content in media objects by modifying the HTML itself, or by adding some custom flexbox CSS to set the <code className="highlighter-rouge">order</code> property (to an integer of your choosing).</p>
  <div className="bd-example">
    <div className="media">
      <div className="media-body">
        <h5 className="mt-0 mb-1">Media object</h5>
        Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.
      </div>
      <svg className="bd-placeholder-img ml-3" width={64} height={64} xmlns="http://www.w3.org/2000/svg" preserveAspectRatio="xMidYMid slice" focusable="false" role="img" aria-label="Placeholder: 64x64"><title>Placeholder</title><rect fill="#868e96" width="100%" height="100%" /><text fill="#dee2e6" dy=".3em" x="50%" y="50%">64x64</text></svg>
    </div>
  </div>
  <div className="bd-clipboard"><button type="button" className="btn-clipboard" title data-original-title="Copy to clipboard">Copy</button></div><figure className="highlight"><pre><code className="language-html" data-lang="html"><span className="nt">&lt;div</span> <span className="na">class=</span><span className="s">"media"</span><span className="nt">&gt;</span>{"\n"}{"  "}<span className="nt">&lt;div</span> <span className="na">class=</span><span className="s">"media-body"</span><span className="nt">&gt;</span>{"\n"}{"    "}<span className="nt">&lt;h5</span> <span className="na">class=</span><span className="s">"mt-0 mb-1"</span><span className="nt">&gt;</span>Media object<span className="nt">&lt;/h5&gt;</span>{"\n"}{"    "}Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.{"\n"}{"  "}<span className="nt">&lt;/div&gt;</span>{"\n"}{"  "}<span className="nt">&lt;img</span> <span className="na">src=</span><span className="s">"..."</span> <span className="na">class=</span><span className="s">"ml-3"</span> <span className="na">alt=</span><span className="s">"..."</span><span className="nt">&gt;</span>{"\n"}<span className="nt">&lt;/div&gt;</span></code></pre></figure>
  <h2 id="media-list"><span className="bd-content-title">Media list</span></h2>
  <p>Because the media object has so few structural requirements, you can also use these classes on list HTML elements. On your <code className="highlighter-rouge">&lt;ul&gt;</code> or <code className="highlighter-rouge">&lt;ol&gt;</code>, add the <code className="highlighter-rouge">.list-unstyled</code> to remove any browser default list styles, and then apply <code className="highlighter-rouge">.media</code> to your <code className="highlighter-rouge">&lt;li&gt;</code>s. As always, use spacing utilities wherever needed to fine tune.</p>
  <div className="bd-example">
    <ul className="list-unstyled">
      <li className="media">
        <svg className="bd-placeholder-img mr-3" width={64} height={64} xmlns="http://www.w3.org/2000/svg" preserveAspectRatio="xMidYMid slice" focusable="false" role="img" aria-label="Placeholder: 64x64"><title>Placeholder</title><rect fill="#868e96" width="100%" height="100%" /><text fill="#dee2e6" dy=".3em" x="50%" y="50%">64x64</text></svg>
        <div className="media-body">
          <h5 className="mt-0 mb-1">List-based media object</h5>
          Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.
        </div>
      </li>
      <li className="media my-4">
        <svg className="bd-placeholder-img mr-3" width={64} height={64} xmlns="http://www.w3.org/2000/svg" preserveAspectRatio="xMidYMid slice" focusable="false" role="img" aria-label="Placeholder: 64x64"><title>Placeholder</title><rect fill="#868e96" width="100%" height="100%" /><text fill="#dee2e6" dy=".3em" x="50%" y="50%">64x64</text></svg>
        <div className="media-body">
          <h5 className="mt-0 mb-1">List-based media object</h5>
          Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.
        </div>
      </li>
      <li className="media">
        <svg className="bd-placeholder-img mr-3" width={64} height={64} xmlns="http://www.w3.org/2000/svg" preserveAspectRatio="xMidYMid slice" focusable="false" role="img" aria-label="Placeholder: 64x64"><title>Placeholder</title><rect fill="#868e96" width="100%" height="100%" /><text fill="#dee2e6" dy=".3em" x="50%" y="50%">64x64</text></svg>
        <div className="media-body">
          <h5 className="mt-0 mb-1">List-based media object</h5>
          Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.
        </div>
      </li>
    </ul>
  </div>
  <div className="bd-clipboard"><button type="button" className="btn-clipboard" title data-original-title="Copy to clipboard">Copy</button></div><figure className="highlight"><pre><code className="language-html" data-lang="html"><span className="nt">&lt;ul</span> <span className="na">class=</span><span className="s">"list-unstyled"</span><span className="nt">&gt;</span>{"\n"}{"  "}<span className="nt">&lt;li</span> <span className="na">class=</span><span className="s">"media"</span><span className="nt">&gt;</span>{"\n"}{"    "}<span className="nt">&lt;img</span> <span className="na">src=</span><span className="s">"..."</span> <span className="na">class=</span><span className="s">"mr-3"</span> <span className="na">alt=</span><span className="s">"..."</span><span className="nt">&gt;</span>{"\n"}{"    "}<span className="nt">&lt;div</span> <span className="na">class=</span><span className="s">"media-body"</span><span className="nt">&gt;</span>{"\n"}{"      "}<span className="nt">&lt;h5</span> <span className="na">class=</span><span className="s">"mt-0 mb-1"</span><span className="nt">&gt;</span>List-based media object<span className="nt">&lt;/h5&gt;</span>{"\n"}{"      "}Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.{"\n"}{"    "}<span className="nt">&lt;/div&gt;</span>{"\n"}{"  "}<span className="nt">&lt;/li&gt;</span>{"\n"}{"  "}<span className="nt">&lt;li</span> <span className="na">class=</span><span className="s">"media my-4"</span><span className="nt">&gt;</span>{"\n"}{"    "}<span className="nt">&lt;img</span> <span className="na">src=</span><span className="s">"..."</span> <span className="na">class=</span><span className="s">"mr-3"</span> <span className="na">alt=</span><span className="s">"..."</span><span className="nt">&gt;</span>{"\n"}{"    "}<span className="nt">&lt;div</span> <span className="na">class=</span><span className="s">"media-body"</span><span className="nt">&gt;</span>{"\n"}{"      "}<span className="nt">&lt;h5</span> <span className="na">class=</span><span className="s">"mt-0 mb-1"</span><span className="nt">&gt;</span>List-based media object<span className="nt">&lt;/h5&gt;</span>{"\n"}{"      "}Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.{"\n"}{"    "}<span className="nt">&lt;/div&gt;</span>{"\n"}{"  "}<span className="nt">&lt;/li&gt;</span>{"\n"}{"  "}<span className="nt">&lt;li</span> <span className="na">class=</span><span className="s">"media"</span><span className="nt">&gt;</span>{"\n"}{"    "}<span className="nt">&lt;img</span> <span className="na">src=</span><span className="s">"..."</span> <span className="na">class=</span><span className="s">"mr-3"</span> <span className="na">alt=</span><span className="s">"..."</span><span className="nt">&gt;</span>{"\n"}{"    "}<span className="nt">&lt;div</span> <span className="na">class=</span><span className="s">"media-body"</span><span className="nt">&gt;</span>{"\n"}{"      "}<span className="nt">&lt;h5</span> <span className="na">class=</span><span className="s">"mt-0 mb-1"</span><span className="nt">&gt;</span>List-based media object<span className="nt">&lt;/h5&gt;</span>{"\n"}{"      "}Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.{"\n"}{"    "}<span className="nt">&lt;/div&gt;</span>{"\n"}{"  "}<span className="nt">&lt;/li&gt;</span>{"\n"}<span className="nt">&lt;/ul&gt;</span></code></pre></figure>
</main>

    );
  }
}